ApzInputField class

Inheritance

Constructors

ApzInputField({Key? key, required String label, required TextEditingController controller, String? hintText, bool obscureText = false, TextInputType keyboardType = TextInputType.text, String? validator(String?)?, Widget? suffixIcon, Widget? prefixIcon, bool enabled = true, bool isEmailFld = false, bool isAmount = false, bool allowAllCaps = false, bool isMandatory = false, bool onlyNumbers = false, void onChanged(String)?, void onFieldSubmitted(String)?, void onTap()?, void onEditingComplete()?, int? maxLength, int maxLines = 1, ApzFieldAppearance appearance = ApzFieldAppearance.primary})
const

Properties

allowAllCaps → bool
final
appearance → ApzFieldAppearance
final
controller → TextEditingController
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
isAmount → bool
final
isEmailFld → bool
final
isMandatory → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType
final
label → String
final
maxLength → int?
final
maxLines → int
final
obscureText → bool
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onFieldSubmitted → void Function(String)?
final
onlyNumbers → bool
final
onTap → void Function()?
final
prefixIcon → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon → Widget?
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited